import React from 'react';
import Badge from '../badge/Badge';
import Checkbox from '../checkbox/Checkbox';
import Flex from '../flex/Flex';
import { Input } from '../input';
import { PaginationProps } from '../pagination/PaginationProps';
import Popover from '../popover/Popover';
import { SelectOption } from '../select/SelectProps';
type ExtendOption = {
    [key: string]: any;
};
export interface TableTranslation {
    noData?: string;
    noGroupData?: string;
    search?: string;
    searchPlaceholder?: string;
    reset?: string;
    colFilter?: string;
    checkboxSelection?: string;
    showAll?: string;
    hideAll?: string;
    rowFilter?: string;
    column?: string;
    operator?: string;
    value?: string;
    group?: string;
    resetFilterBtn?: string;
    export?: string;
    exportRaw?: string;
    exportSelected?: string;
    exportAll?: string;
    exportFilter?: string;
    sort?: string;
    sortTooltipAscend?: string;
    sortTooltipDescend?: string;
    sortTooltipCancel?: string;
    addAnotherSort?: string;
    ascending?: string;
    descending?: string;
    sortDefault?: string;
    selectColumn?: string;
    filterOperators?: {
        isEmpty?: string;
        isNotEmpty?: string;
        is?: string;
        isNot?: string;
        and?: string;
        or?: string;
        contains?: string;
        equals?: string;
        startWith?: string;
        endWith?: string;
        isBefore?: string;
        isAfter?: string;
        isOnOrBefore?: string;
        isOnOrAfter?: string;
    };
}
export interface ControlCommon {
    translation?: TableTranslation;
    showControlTitle?: boolean;
    ControlBadgeProps?: React.ComponentProps<typeof Badge>;
    showControlTitleTooltip?: boolean;
}
export interface ControlState {
    sorting: Sorting[];
    keyword: string;
    filters: Filter[];
}
export type OnFilterValue = ControlState & {
    hiddenCols: string[];
};
export interface SortOptions {
    /** Sort function for ascending sort, see Array.sort's compareFunction */
    compare?: (a: any, b: any) => number;
    /** Config the priority of sort columns. (default: undefined) */
    multiple?: number;
    /** Default order of sorted values. (default: null) */
    defaultOrder?: string;
}
export interface Sorting extends SortOptions {
    key: string;
    type: string;
}
export interface SearchControl {
    /** Fields used to search when autoSearch = false (default: all) */
    fields?: 'all' | string[];
    /** Auto search when typing with (debounce: 250ms) */
    searchOnTyping?: boolean;
    /** Auto search (default: true) */
    autoSearch?: boolean;
    /** Customize the search method of a key */
    customSearchFn?: {
        [key: string]: (value: any, keyword: string) => boolean;
    };
    /** show searchbar instead of search control */
    showSearchBarOnly?: boolean;
    /** Future feature */
    /** Auto highlight keyword in result list (default: false) */
    autoHighlight?: boolean;
    /** Default search keyword */
    defaultKeyword?: string;
    /** Custom search input */
    InputProps?: React.ComponentProps<typeof Input>;
}
export type FilterType = 'number' | 'text' | 'date';
export interface FilterField {
    key: string;
    title: string;
    type: FilterType | SelectOption[];
}
export interface Filter {
    id: string;
    column?: string;
    op?: string;
    value?: any;
    logical?: string;
}
export interface FilterItemProp {
    filter: Filter;
    fields: FilterField[];
    hideDelIcon?: boolean;
    translation?: TableTranslation;
    onFilterChange: (id: string, changedFilter: any) => void;
    onDelete: (id: string) => void;
}
export type RowFilterControl = {
    [key: string]: FilterType | SelectOption[];
};
export interface TableSearchProps extends ControlCommon {
    control: SearchControl;
    resetFlag: boolean;
    onSearch?: (keyword: string) => any;
    ControlPopoverProps?: React.ComponentProps<typeof Popover>;
}
export interface TableColFilterProps extends ControlCommon {
    selection?: boolean;
    columns: Array<Pick<TableColumn, 'key' | 'title'>>;
    onFilter: (hiddenCols: string[]) => void;
    resetFlag: boolean;
    ControlPopoverProps?: React.ComponentProps<typeof Popover>;
}
export interface TableRowFilterProps extends ControlCommon {
    control: RowFilterControl;
    columns: Array<Pick<TableColumn, 'key' | 'title'>>;
    onFilter: (filters: Filter[]) => any;
    resetFlag: boolean;
    ControlPopoverProps?: React.ComponentProps<typeof Popover>;
}
export interface TableSortProps extends ControlCommon {
    sorting?: Sorting[];
    columns: Array<{
        key: string;
        title: string;
    }>;
    onSortChange: (key: string, type: string) => void;
    onSortDelete: (key: string) => void;
    onSortOrderChange: (key: string, isIncrease: boolean) => void;
    onAddSort: (key: string) => void;
    ControlPopoverProps?: React.ComponentProps<typeof Popover>;
}
export interface TableRowOptions {
    /** even table selection = true, this row will also be unselectable (default: false)  */
    disabledSelection?: boolean;
    /** Customize tr element  */
    trProps?: React.HTMLAttributes<HTMLTableRowElement>;
}
export interface TableRow extends ExtendOption {
    key?: string | number;
    rowOptions?: TableRowOptions;
    groupKey?: string;
}
export interface TableColumn<T = any> {
    /** Unique key of this column */
    key: keyof T;
    /** Title of this column */
    title: string;
    /** th colSpan, set to 0, the cell will not be rendered. (default: -1) */
    colSpan?: number;
    /** The className of this column */
    thClassName?: string;
    /** Renderer content of the table cell. The return value should be a ReactNode (default: undefined) */
    render?: (value: T[keyof T], record: T, index: number) => React.ReactNode;
    /** Renderer customize prop of the table cell. The return value should be a ReactNode (default: undefined) */
    renderTdProps?: (value: any, record: TableRow, index: number) => React.DetailedHTMLProps<React.TdHTMLAttributes<HTMLTableCellElement>, HTMLTableCellElement>;
    renderHeader?: (title: string) => React.ReactNode;
    /** The specify which way that column is aligned (default: left) */
    align?: 'left' | 'center' | 'right';
    /** Set max width to enable text-overflow: ellipsis, -1 to disabled. (default: -1) */
    maxWidth?: number;
    /** Column min width */
    minWidth?: number;
    /** Column width (apply for table fixed or fixed column) */
    /** Set column to be fixed (default: undefined) */
    /** Setup sort option */
    sorter?: SortOptions;
}
export interface TableGroup {
    key: string;
    label: React.ReactNode;
    defaultCollapse?: boolean;
    /** Show empty label if empty data (default: false) */
    showEmpty?: boolean;
}
export interface TableProps {
    columns: TableColumn[];
    rows?: TableRow[];
    /** Loading effect (default: false) */
    loading?: true | React.ReactNode;
    /** table-layout: fixed; (default: false) */
    fixedLayout?: boolean;
    /** Specify field in row is unique key (default: 'key') */
    keyField?: string;
    /** Border style (default: undefined) */
    bordered?: 'row' | 'column' | 'both';
    /** Change background color when hover (default: false) */
    hoverable?: boolean;
    /** Use striped to add zebra-striping to any table row within the tbody (default: undefined) */
    striped?: 'odd' | 'even';
    /** If true, compact vertical padding designed for keyboard and mouse input is used for the list and list items. The prop is available to descendant components as the dense context. (default: false) */
    dense?: boolean;
    /** Set the header sticky. (default: false) */
    stickyHeader?: boolean;
    /** Add table header */
    header?: React.ReactNode;
    /** (default: "No data available in table") */
    noData?: React.ReactNode;
    /** Custom group to collapse/expand (default: []) */
    groups?: TableGroup[];
    /** Allow row selection (default: selection: false, allowSelectAll: true) */
    selection?: boolean;
    allowSelectAll?: boolean;
    selectionTdProps?: React.HTMLAttributes<HTMLTableCellElement>;
    CheckboxProps?: React.ComponentProps<typeof Checkbox>;
    onRowSelectChange?: (selected: TableRow[], record?: TableRow) => any;
    /** If true, the table will automatically filter when the filter changes (default: true) */
    autoFilter?: boolean;
    /** Search control */
    searchControl?: SearchControl;
    /** Column filter (hide/show columns) control (default: false) */
    columnFilterControl?: boolean;
    /** Sort control (default: true) */
    sortControl?: boolean;
    /** Columns do not support sorting Array<key> */
    excludeSortFields?: string[];
    /** Row filter control (default: false) */
    rowFilterControl?: RowFilterControl;
    /** Controls whether the control title is show (default: false) */
    showControlTitle?: boolean;
    /** Show control tooltip when showControlTitle = false (default: false) */
    showControlTitleTooltip?: boolean;
    /** Controls whether the reset filter button is show (default: true) */
    showResetFilter?: boolean;
    /** Show divider between th */
    showThDivider?: boolean;
    /** Add other control in control bar */
    additionalControl?: React.ReactNode;
    /** Trigger when the filter, control changes */
    onFilter?: (filter: OnFilterValue) => any;
    onResetFilter?: () => any;
    /** Custom pagination, autoPaginate default false */
    autoPaginate?: boolean;
    onPaginate?: (paginated: {
        page: number;
        pageSize: number;
    }, control: OnFilterValue) => any;
    PaginationProps?: Partial<PaginationProps>;
    paginationPosition?: 'flex-end' | 'center' | 'flex-start';
    /** Custom export data, default allowExport: false */
    allowExport?: boolean;
    customExport?: (record: TableRow) => any;
    /** Render under control bar */
    controlSummary?: React.ReactNode;
    /** Render table footer (summary) */
    summary?: React.ReactNode;
    /** Customize */
    ControlFlexProps?: React.ComponentProps<typeof Flex>;
    ControlBadgeProps?: React.ComponentProps<typeof Badge>;
    ControlPopoverProps?: React.ComponentProps<typeof Popover>;
    /** Support translate */
    translation?: TableTranslation;
    /** Add class name, style to the root element */
    className?: string;
    style?: React.CSSProperties;
    /** The ref is forwarded to the root element. */
    ref?: React.Ref<HTMLDivElement>;
}
export {};
